@@ -116,12 +116,7 @@ ROOT_URLCONF = 'demoproject.urls'
 # Python dotted path to the WSGI application used by Django's runserver.
 WSGI_APPLICATION = 'demoproject.wsgi.application'
 
-TEMPLATE_DIRS = (
-    # Put strings here, like "/home/html/django_templates" or "C:/www/django/templates".
-    # Always use forward slashes, even on Windows.
-    # Don't forget to use absolute paths, not relative paths.
-    os.path.join(APPLICATION_DIR, 'templates')
-)
+TEMPLATE_DIRS = ( os.path.join(APPLICATION_DIR, 'templates'), )
 
 INSTALLED_APPS = (
     'django.contrib.auth',
